==> haskell-lift-type-0.1.2.0-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-8EINegmWmqKLB5nFDeohwu
key:                  lift-type-0.1.2.0-8EINegmWmqKLB5nFDeohwu
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  46bca01875f6860f191c8f43c5f398ba
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-8EINegmWmqKLB5nFDeohwu
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lift-type-0.1.2.0-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-HGVUvluWWsiiyiNRKq9G1
key:                  lift-type-0.1.2.0-HGVUvluWWsiiyiNRKq9G1
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  9a4c4ba98281d6210fdb54ebc924468d
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-HGVUvluWWsiiyiNRKq9G1
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
